package com.eco.plugin.xx.bjgjlog.function;

import com.eco.plugin.xx.bjgjlog.config.PluginLogSimpleConfig;
import com.eco.plugin.xx.bjgjlog.db.bean.TimeRecordEntity;
import com.eco.plugin.xx.bjgjlog.db.controller.DBController;
import com.eco.plugin.xx.bjgjlog.utils.DateUtilSelf;
import com.eco.plugin.xx.bjgjlog.utils.FRUtils;
import com.eco.plugin.xx.bjgjlog.utils.HttpUtils;
import com.eco.plugin.xx.bjgjlog.utils.Utils;
import com.fr.general.data.DataModel;
import com.fr.general.data.TableDataException;
import com.fr.json.JSONArray;
import com.fr.json.JSONObject;
import com.fr.plugin.context.PluginContexts;
import com.fr.script.AbstractFunction;
import com.fr.stable.fun.Authorize;

import java.util.HashMap;
import java.util.Map;

@Authorize(callSignKey = "com.eco.plugin.xx.bjgjlog")
public class AuthFunction extends AbstractFunction {

    @Override
    public Object run(Object[] objects) {
        FRUtils.FRLogInfo("日志推送");
        if(!PluginContexts.currentContext().isAvailable()){
            return "FAIL";
        }
        String now = DateUtilSelf.getNow();
        //获取配置参数
        PluginLogSimpleConfig psc = PluginLogSimpleConfig.getInstance();
        //从数据集获取日志数组
        JSONArray logs = null;
        FRUtils.FRLogInfo("获取数据集开始");
        try {
            logs = getLogArray(psc);
        } catch (TableDataException e) {
            FRUtils.FRLogError("获取数据集数据失败:"+e.getMessage());
            return "FAIL";
        }
        FRUtils.FRLogInfo("获取数据集结束");

        //推送日志，根据返回值选择返回true or false
        JSONObject param = new JSONObject();
        param.put("operLogs",logs);

        FRUtils.FRLogInfo("推送开始");
        FRUtils.FRLogInfo(param.toString());
        Map<String,String> header = new HashMap<String,String>();
        header.put("appId",psc.getAppid());
        header.put("appSecret",psc.getAppSecret());
        String result = HttpUtils.HttpPostJson(psc.getRjjk(),param.toString(),header);
        FRUtils.FRLogInfo("推送结束");

        if(Utils.isNullStr(result)){
            FRUtils.FRLogError("推送日志失败");
            return "FAIL";
        }

        JSONObject resultJson = new JSONObject(result);
        int code = resultJson.getInt("code");

        if(200 != code){
            FRUtils.FRLogError("推送日志失败:"+resultJson.getString("msg"));
            return "FAIL";
        }
        FRUtils.FRLogInfo("推送结束2");

        TimeRecordEntity tre = new TimeRecordEntity();
        tre.setTime(now);
        FRUtils.FRLogInfo("addRecord开始");

        DBController.addRecord(tre);
        FRUtils.FRLogInfo("addRecord开始");

        return "SUCCESS";
    }

    private JSONArray getLogArray(PluginLogSimpleConfig psc) throws TableDataException {
        DataModel dm = FRUtils.getTableData(psc.getDataset());
        int rowcount = dm.getRowCount();

        int appIdIndex = dm.getColumnIndex("appId");
        int titleIndex = dm.getColumnIndex("title");
        int businessTypeIndex = dm.getColumnIndex("businessType");
        int methodIndex = dm.getColumnIndex("method");
        int requestMethodIndex = dm.getColumnIndex("requestMethod");
        int operatorTypeIndex = dm.getColumnIndex("operatorType");
        int operNameIndex = dm.getColumnIndex("operName");
        int operUrlIndex = dm.getColumnIndex("operUrl");
        int operIpIndex = dm.getColumnIndex("operIp");
        int operParamIndex = dm.getColumnIndex("operParam");
        int jsonResultIndex = dm.getColumnIndex("jsonResult");
        int statusIndex = dm.getColumnIndex("status");
        int tenantIdIndex = dm.getColumnIndex("tenantId");
        int operTimeIndex = dm.getColumnIndex("operTime");

        JSONArray result = new JSONArray();

        for(int i =0;i<rowcount;i++){
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("appId",dm.getValueAt(i,appIdIndex));
            jsonObject.put("title",String.valueOf(dm.getValueAt(i,titleIndex)));
            jsonObject.put("businessType",String.valueOf(dm.getValueAt(i,businessTypeIndex)));
            jsonObject.put("method",String.valueOf(dm.getValueAt(i,methodIndex)));
            jsonObject.put("requestMethod",String.valueOf(dm.getValueAt(i,requestMethodIndex)));
            jsonObject.put("operatorType",String.valueOf(dm.getValueAt(i,operatorTypeIndex)));
            jsonObject.put("operName",String.valueOf(dm.getValueAt(i,operNameIndex)));
            jsonObject.put("operUrl",String.valueOf(dm.getValueAt(i,operUrlIndex)));
            jsonObject.put("operIp",String.valueOf(dm.getValueAt(i,operIpIndex)));
            jsonObject.put("operParam",String.valueOf(dm.getValueAt(i,operParamIndex)));
            jsonObject.put("jsonResult",String.valueOf(dm.getValueAt(i,jsonResultIndex)));
            jsonObject.put("status",String.valueOf(dm.getValueAt(i,statusIndex)));
            jsonObject.put("tenantId",String.valueOf(dm.getValueAt(i,tenantIdIndex)));
            jsonObject.put("operTime",String.valueOf(dm.getValueAt(i,operTimeIndex)));

            result.add(jsonObject);
        }

        return result;
    }
}
